@@ -46,9 +46,8 @@ class DBHelper(metaclass=_MetaSingleton):
 
     @contextmanager
     def auto_commit(self):
-
         try:
             yield self.db
-            self.db.commit()
+            self.db.session.commit()
         except Exception as e:
-            self.db.rollback()
+            self.db.session.rollback()
